pub struct DefaultLogArgs { /* private fields */ }Expand description
Default values for log configuration that can be customized.
Global defaults can be set via DefaultLogArgs::try_init.
Implementations
Sourceimpl DefaultLogArgs
impl DefaultLogArgs
Sourcepub fn try_init(self) -> Result<(), Self>
pub fn try_init(self) -> Result<(), Self>
Initialize the global log defaults with this configuration.
Sourcepub fn get_global() -> &'static Self
pub fn get_global() -> &'static Self
Get a reference to the global log defaults.
Sourcepub const fn with_log_stdout_format(self, v: LogFormat) -> Self
pub const fn with_log_stdout_format(self, v: LogFormat) -> Self
Set the default stdout log format.
Sourcepub fn with_log_stdout_filter(self, v: String) -> Self
pub fn with_log_stdout_filter(self, v: String) -> Self
Set the default stdout log filter.
Sourcepub const fn with_log_file_format(self, v: LogFormat) -> Self
pub const fn with_log_file_format(self, v: LogFormat) -> Self
Set the default file log format.
Sourcepub fn with_log_file_filter(self, v: String) -> Self
pub fn with_log_file_filter(self, v: String) -> Self
Set the default file log filter.
Sourcepub fn with_log_file_name(self, v: String) -> Self
pub fn with_log_file_name(self, v: String) -> Self
Set the default log file name.
Sourcepub const fn with_log_file_max_size(self, v: u64) -> Self
pub const fn with_log_file_max_size(self, v: u64) -> Self
Set the default max log file size in MB.
Sourcepub const fn with_journald(self, v: bool) -> Self
pub const fn with_journald(self, v: bool) -> Self
Set whether journald logging is enabled by default.
Sourcepub fn with_journald_filter(self, v: String) -> Self
pub fn with_journald_filter(self, v: String) -> Self
Set the default journald filter.
Sourcepub const fn with_samply(self, v: bool) -> Self
pub const fn with_samply(self, v: bool) -> Self
Set whether samply tracing is enabled by default.
Sourcepub fn with_samply_filter(self, v: String) -> Self
pub fn with_samply_filter(self, v: String) -> Self
Set the default samply filter.
Sourcepub const fn with_tracy(self, v: bool) -> Self
pub const fn with_tracy(self, v: bool) -> Self
Set whether tracy tracing is enabled by default.
Sourcepub fn with_tracy_filter(self, v: String) -> Self
pub fn with_tracy_filter(self, v: String) -> Self
Set the default tracy filter.
Sourcepub const fn with_color(self, v: ColorMode) -> Self
pub const fn with_color(self, v: ColorMode) -> Self
Set the default color mode.