pub struct DefaultNetworkArgs {Show 14 fields
pub dns_retries: usize,
pub nat: NatResolver,
pub addr: IpAddr,
pub port: u16,
pub max_concurrent_tx_requests: u32,
pub max_concurrent_tx_requests_per_peer: u8,
pub max_seen_tx_history: u32,
pub max_pending_pool_imports: usize,
pub soft_limit_byte_size_pooled_transactions_response: usize,
pub soft_limit_byte_size_pooled_transactions_response_on_pack_request: usize,
pub max_capacity_cache_txns_pending_fetch: u32,
pub tx_propagation_policy: TransactionPropagationKind,
pub tx_ingress_policy: TransactionIngressPolicy,
pub propagation_mode: TransactionPropagationMode,
}Expand description
Default values for network CLI arguments that can be customized.
Global defaults can be set via DefaultNetworkArgs::try_init.
Fields
dns_retries: usizeDefault DNS retries.
nat: NatResolverDefault NAT resolver.
addr: IpAddrDefault network listening address.
port: u16Default network listening port.
max_concurrent_tx_requests: u32Default max concurrent GetPooledTransactions requests.
max_concurrent_tx_requests_per_peer: u8Default max concurrent GetPooledTransactions requests per peer.
max_seen_tx_history: u32Default max number of seen transactions to remember per peer.
max_pending_pool_imports: usizeDefault max number of transactions to import concurrently.
soft_limit_byte_size_pooled_transactions_response: usizeDefault max accumulated byte size of transactions to pack in one response.
soft_limit_byte_size_pooled_transactions_response_on_pack_request: usizeDefault max accumulated byte size of transactions to request in one request.
max_capacity_cache_txns_pending_fetch: u32Default max capacity of cache of hashes for transactions pending fetch.
tx_propagation_policy: TransactionPropagationKindDefault transaction propagation policy.
tx_ingress_policy: TransactionIngressPolicyDefault transaction ingress policy.
propagation_mode: TransactionPropagationModeDefault transaction propagation mode.
Implementations
Sourceimpl DefaultNetworkArgs
impl DefaultNetworkArgs
Sourcepub fn try_init(self) -> Result<(), Self>
pub fn try_init(self) -> Result<(), Self>
Initialize the global network defaults with this configuration.
Sourcepub fn get_global() -> &'static Self
pub fn get_global() -> &'static Self
Get a reference to the global network defaults.
Sourcepub const fn with_dns_retries(self, v: usize) -> Self
pub const fn with_dns_retries(self, v: usize) -> Self
Set the default DNS retries.
Sourcepub const fn with_max_concurrent_tx_requests(self, v: u32) -> Self
pub const fn with_max_concurrent_tx_requests(self, v: u32) -> Self
Set the default max concurrent GetPooledTransactions requests.
Sourcepub const fn with_max_concurrent_tx_requests_per_peer(self, v: u8) -> Self
pub const fn with_max_concurrent_tx_requests_per_peer(self, v: u8) -> Self
Set the default max concurrent GetPooledTransactions requests per peer.
Sourcepub const fn with_max_seen_tx_history(self, v: u32) -> Self
pub const fn with_max_seen_tx_history(self, v: u32) -> Self
Set the default max number of seen transactions to remember per peer.
Sourcepub const fn with_max_pending_pool_imports(self, v: usize) -> Self
pub const fn with_max_pending_pool_imports(self, v: usize) -> Self
Set the default max number of transactions to import concurrently.
Sourcepub const fn with_soft_limit_byte_size_pooled_transactions_response(
self,
v: usize,
) -> Self
pub const fn with_soft_limit_byte_size_pooled_transactions_response( self, v: usize, ) -> Self
Set the default max accumulated byte size of transactions to pack in one response.
Sourcepub const fn with_soft_limit_byte_size_pooled_transactions_response_on_pack_request(
self,
v: usize,
) -> Self
pub const fn with_soft_limit_byte_size_pooled_transactions_response_on_pack_request( self, v: usize, ) -> Self
Set the default max accumulated byte size of transactions to request in one request.
Sourcepub const fn with_max_capacity_cache_txns_pending_fetch(self, v: u32) -> Self
pub const fn with_max_capacity_cache_txns_pending_fetch(self, v: u32) -> Self
Set the default max capacity of cache of hashes for transactions pending fetch.
Sourcepub const fn with_tx_propagation_policy(
self,
v: TransactionPropagationKind,
) -> Self
pub const fn with_tx_propagation_policy( self, v: TransactionPropagationKind, ) -> Self
Set the default transaction propagation policy.
Sourcepub const fn with_tx_ingress_policy(self, v: TransactionIngressPolicy) -> Self
pub const fn with_tx_ingress_policy(self, v: TransactionIngressPolicy) -> Self
Set the default transaction ingress policy.
Sourcepub const fn with_propagation_mode(self, v: TransactionPropagationMode) -> Self
pub const fn with_propagation_mode(self, v: TransactionPropagationMode) -> Self
Set the default transaction propagation mode.