Enum SealedOrRecoveredBlock
pub enum SealedOrRecoveredBlock<B>where
B: Block,{
Sealed(Arc<SealedBlock<B>>),
Recovered(Arc<RecoveredBlock<B>>),
}Expand description
A block that is either sealed or sealed with recovered transaction senders.
This is useful for APIs that must accept ordinary sealed blocks, but can skip sender recovery
when the caller already has a RecoveredBlock.
Variants
Sealed(Arc<SealedBlock<B>>)
A sealed block without recovered senders.
Recovered(Arc<RecoveredBlock<B>>)
A sealed block with recovered senders.
Implementations
impl<B> SealedOrRecoveredBlock<B>where
B: Block,
impl<B> SealedOrRecoveredBlock<B>where
B: Block,
pub fn sealed(block: SealedBlock<B>) -> SealedOrRecoveredBlock<B>
pub fn sealed(block: SealedBlock<B>) -> SealedOrRecoveredBlock<B>
Creates a SealedOrRecoveredBlock from a sealed block.
pub const fn sealed_arc(block: Arc<SealedBlock<B>>) -> SealedOrRecoveredBlock<B>
pub const fn sealed_arc(block: Arc<SealedBlock<B>>) -> SealedOrRecoveredBlock<B>
Creates a SealedOrRecoveredBlock from a shared sealed block.
pub fn recovered(block: RecoveredBlock<B>) -> SealedOrRecoveredBlock<B>
pub fn recovered(block: RecoveredBlock<B>) -> SealedOrRecoveredBlock<B>
Creates a SealedOrRecoveredBlock from a recovered block.
pub const fn recovered_arc(
block: Arc<RecoveredBlock<B>>,
) -> SealedOrRecoveredBlock<B>
pub const fn recovered_arc( block: Arc<RecoveredBlock<B>>, ) -> SealedOrRecoveredBlock<B>
Creates a SealedOrRecoveredBlock from a shared recovered block.
pub fn sealed_block(&self) -> &SealedBlock<B>
pub fn sealed_block(&self) -> &SealedBlock<B>
Returns the sealed block view.
pub fn recovered_block(&self) -> Option<&RecoveredBlock<B>>
pub fn recovered_block(&self) -> Option<&RecoveredBlock<B>>
Returns the recovered block if this block has recovered senders.
pub fn into_sealed_block(self) -> SealedBlock<B>
pub fn into_sealed_block(self) -> SealedBlock<B>
Consumes this block and returns the sealed block.
pub fn into_recovered_block(
self,
) -> Result<RecoveredBlock<B>, BlockRecoveryError<SealedBlock<B>>>
pub fn into_recovered_block( self, ) -> Result<RecoveredBlock<B>, BlockRecoveryError<SealedBlock<B>>>
Consumes this block and returns the recovered block, recovering sealed-only blocks if needed.
Methods from Deref<Target = SealedBlock<B>>
pub fn hash_ref(&self) -> &FixedBytes<32>
pub fn hash_ref(&self) -> &FixedBytes<32>
Returns a reference to the block hash.
pub fn hash(&self) -> FixedBytes<32>
pub fn hash(&self) -> FixedBytes<32>
Returns the block hash.
pub fn clone_block(&self) -> B
pub fn clone_block(&self) -> B
Clones the wrapped block.
pub fn rlp_length(&self) -> usize
pub fn rlp_length(&self) -> usize
Returns the length of the block.
pub fn senders(&self) -> Result<Vec<Address>, RecoveryError>
pub fn senders(&self) -> Result<Vec<Address>, RecoveryError>
Recovers all senders from the transactions in the block.
Returns an error if any of the transactions fail to recover the sender.
pub fn num_hash(&self) -> NumHash
pub fn num_hash(&self) -> NumHash
Return the number hash tuple.
pub fn block_with_parent(&self) -> BlockWithParent
pub fn block_with_parent(&self) -> BlockWithParent
Return a [BlockWithParent] for this header.
pub fn sealed_header(&self) -> &SealedHeader<<B as Block>::Header>
pub fn sealed_header(&self) -> &SealedHeader<<B as Block>::Header>
Returns the Sealed header.
pub fn sealed_header_ref(&self) -> SealedHeader<&<B as Block>::Header>
pub fn sealed_header_ref(&self) -> SealedHeader<&<B as Block>::Header>
Returns the wrapped SealedHeader<B::Header> as SealedHeader<&B::Header>.
pub fn clone_sealed_header(&self) -> SealedHeader<<B as Block>::Header>
pub fn clone_sealed_header(&self) -> SealedHeader<<B as Block>::Header>
Clones the wrapped header and returns a SealedHeader sealed with the hash.
pub fn blob_versioned_hashes_iter(
&self,
) -> impl Iterator<Item = &FixedBytes<32>>
pub fn blob_versioned_hashes_iter( &self, ) -> impl Iterator<Item = &FixedBytes<32>>
Returns an iterator over all blob versioned hashes from the block body.
pub fn transaction_count(&self) -> usize
pub fn transaction_count(&self) -> usize
Returns the number of transactions in the block.
pub fn ensure_transaction_root_valid(
&self,
) -> Result<(), GotExpected<FixedBytes<32>>>
pub fn ensure_transaction_root_valid( &self, ) -> Result<(), GotExpected<FixedBytes<32>>>
Ensures that the transaction root in the block header is valid.
The transaction root is the Keccak 256-bit hash of the root node of the trie structure populated with each transaction in the transactions list portion of the block.
Returns
Returns Ok(()) if the calculated transaction root matches the one stored in the header,
indicating that the transactions in the block are correctly represented in the trie.
Returns Err(error) if the transaction root validation fails, providing a GotExpected
error containing the calculated and expected roots.