Recovered

Struct Recovered 

pub struct Recovered<T> { /* private fields */ }
A signed object paired with a previously recovered signer.

The signer is cached metadata and is not recomputed. Mapping or mutating the inner value is valid only when it preserves the signed payload and signature preimage.

Implementations



impl<T> Recovered<T>

pub const fn signer(&self) -> Address

Signer of the object recovered from signature

pub const fn signer_ref(&self) -> &Address

Reference to the signer of the object recovered from signature

pub const fn inner(&self) -> &T

Returns a reference to the inner recovered object.

pub const fn inner_mut(&mut self) -> &mut T

Returns a mutable reference to the inner recovered object.

This does not update or invalidate the cached signer.

pub fn into_inner(self) -> T

Reference to the inner signed object.

pub fn clone_inner(&self) -> T
where T: Clone,

Clone the inner signed object.

pub fn into_parts(self) -> (T, Address)

Dissolve Self to its component

pub const fn as_recovered_ref(&self) -> Recovered<&T>

Converts from &Recovered<T> to Recovered<&T>.

pub const fn new_unchecked(inner: T, signer: Address) -> Recovered<T>

Create Recovered from the given transaction and [Address] of the signer.

Note: This does not check if the signer is the actual signer of the transaction.

pub fn convert<Tx>(self) -> Recovered<Tx>
where Tx: From<T>,

Converts the inner signed object while preserving the signer without validation.

pub fn try_convert<Tx>(self) -> Result<Recovered<Tx>, <Tx as TryFrom<T>>::Error>
where Tx: TryFrom<T>,

Fallibly converts the inner signed object while preserving the signer without validation.

pub fn map<Tx>(self, f: impl FnOnce(T) -> Tx) -> Recovered<Tx>

Applies a closure while preserving the signer without validation.

pub fn try_map<Tx, E>( self, f: impl FnOnce(T) -> Result<Tx, E>, ) -> Result<Recovered<Tx>, E>

Applies a fallible closure while preserving the signer without validation.

pub fn into_encoded_with( self, encoding: impl Into<Bytes>, ) -> WithEncoded<Recovered<T>>

Returns the WithEncoded representation of Recovered with the given encoding.

pub fn into_encoded(self) -> WithEncoded<Recovered<T>>
where T: Encodable2718,

Encodes the inner type and returns the WithEncoded representation of Recovered.



impl<T> Recovered<&T>

pub fn cloned(self) -> Recovered<T>
where T: Clone,

Maps a Recovered<&T> to a Recovered<T> by cloning the transaction.

pub const fn copied(&self) -> Recovered<&T>

Helper function to explicitly create a new copy of Recovered<&T>



impl<T> Recovered<Cow<'_, T>>
where T: Clone,

pub fn into_owned(self) -> Recovered<T>

Converts Recovered<Cow<'_, T>> into Recovered<T> by cloning the borrowed data if necessary.