Struct SealedBlockWith
pub struct SealedBlockWith<B, T>where
B: Block,{ /* private fields */ }Expand description
A SealedBlock paired with associated data.
This is useful for workflows that need to carry block-adjacent metadata alongside a sealed block without defining a new wrapper type for each metadata payload.
Implementations
impl<B, T> SealedBlockWith<B, T>where
B: Block,
impl<B, T> SealedBlockWith<B, T>where
B: Block,
pub const fn new(block: SealedBlock<B>, data: T) -> SealedBlockWith<B, T>
pub const fn new(block: SealedBlock<B>, data: T) -> SealedBlockWith<B, T>
Creates a new sealed block with associated data.
pub const fn block(&self) -> &SealedBlock<B>
pub const fn block(&self) -> &SealedBlock<B>
Returns the sealed block.
pub fn split(self) -> (SealedBlock<B>, T)
pub fn split(self) -> (SealedBlock<B>, T)
Consumes the type and returns its components.
impl<B, T> SealedBlockWith<B, Option<T>>where
B: Block,
impl<B, T> SealedBlockWith<B, Option<T>>where
B: Block,
pub const fn from_block(block: SealedBlock<B>) -> SealedBlockWith<B, Option<T>>
pub const fn from_block(block: SealedBlock<B>) -> SealedBlockWith<B, Option<T>>
Creates a sealed block without associated data.
Methods from Deref<Target = SealedBlock<B>>
pub fn hash_ref(&self) -> &FixedBytes<32>
pub fn hash_ref(&self) -> &FixedBytes<32>
Returns a reference to the block hash.
pub fn hash(&self) -> FixedBytes<32>
pub fn hash(&self) -> FixedBytes<32>
Returns the block hash.
pub fn clone_block(&self) -> B
pub fn clone_block(&self) -> B
Clones the wrapped block.
pub fn rlp_length(&self) -> usize
pub fn rlp_length(&self) -> usize
Returns the length of the block.
pub fn senders(&self) -> Result<Vec<Address>, RecoveryError>
pub fn senders(&self) -> Result<Vec<Address>, RecoveryError>
Recovers all senders from the transactions in the block.
Returns an error if any of the transactions fail to recover the sender.
pub fn num_hash(&self) -> NumHash
pub fn num_hash(&self) -> NumHash
Return the number hash tuple.
pub fn block_with_parent(&self) -> BlockWithParent
pub fn block_with_parent(&self) -> BlockWithParent
Return a [BlockWithParent] for this header.
pub fn sealed_header(&self) -> &SealedHeader<<B as Block>::Header>
pub fn sealed_header(&self) -> &SealedHeader<<B as Block>::Header>
Returns the Sealed header.
pub fn sealed_header_ref(&self) -> SealedHeader<&<B as Block>::Header>
pub fn sealed_header_ref(&self) -> SealedHeader<&<B as Block>::Header>
Returns the wrapped SealedHeader<B::Header> as SealedHeader<&B::Header>.
pub fn clone_sealed_header(&self) -> SealedHeader<<B as Block>::Header>
pub fn clone_sealed_header(&self) -> SealedHeader<<B as Block>::Header>
Clones the wrapped header and returns a SealedHeader sealed with the hash.
pub fn blob_versioned_hashes_iter(
&self,
) -> impl Iterator<Item = &FixedBytes<32>>
pub fn blob_versioned_hashes_iter( &self, ) -> impl Iterator<Item = &FixedBytes<32>>
Returns an iterator over all blob versioned hashes from the block body.
pub fn transaction_count(&self) -> usize
pub fn transaction_count(&self) -> usize
Returns the number of transactions in the block.
pub fn ensure_transaction_root_valid(
&self,
) -> Result<(), GotExpected<FixedBytes<32>>>
pub fn ensure_transaction_root_valid( &self, ) -> Result<(), GotExpected<FixedBytes<32>>>
Ensures that the transaction root in the block header is valid.
The transaction root is the Keccak 256-bit hash of the root node of the trie structure populated with each transaction in the transactions list portion of the block.
Returns
Returns Ok(()) if the calculated transaction root matches the one stored in the header,
indicating that the transactions in the block are correctly represented in the trie.
Returns Err(error) if the transaction root validation fails, providing a GotExpected
error containing the calculated and expected roots.