Trait TxHashRef
pub trait TxHashRef {
// Required method
fn tx_hash(&self) -> &FixedBytes<32>;
}Expand description
Trait for types that provide access to a transaction hash reference.
This trait is implemented by types that contain or can provide a reference to a
transaction hash ([TxHash]). It provides a standard interface for accessing
transaction hashes without requiring ownership.
Required Methods
fn tx_hash(&self) -> &FixedBytes<32>
fn tx_hash(&self) -> &FixedBytes<32>
Returns a reference to the transaction hash.
This assumes the implementing type already owns or has computed the transaction hash.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".